==> bomojo-0.7.0.tar.gz: bomojo-0.7.0/bomojo/matchups/tests/test_forms.py <==
from django.contrib.auth.models import User
from django.test import RequestFactory, TestCase

from bomojo.matchups.forms import MatchupForm
from bomojo.matchups.tests.helpers import create_movie


class MatchupFormTest(TestCase):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        create_movie('Foo')
        create_movie('Foo 2', external_id='foo2')
        create_movie('Foo 3', external_id='foo3')
        create_movie('Bar')

    def setUp(self):
        super().setUp()
        self.user = User.objects.create(username='joe',
                                        email='joe@example.com',
                                        password='top_secret')
        self.request = RequestFactory().post('/matchup')

        # Simulate the user being authenticated.
        self.request.user = self.user

    def test_happy_path(self):
        form = MatchupForm(self.request, {
            'title': 'foo trilogy',
            'description': 'The entire foo trilogy',
            'movies': ['foo', 'bar'],
            'period': '30d'
        })

        self.assertTrue(form.is_valid(), form.errors)

        matchup = form.save()

        self.assertEqual(matchup.title, 'foo trilogy')
        self.assertEqual(matchup.description, 'The entire foo trilogy')
        self.assertEqual(matchup.movies, ['foo', 'bar'])
        self.assertEqual(matchup.period, '30d')

    def test_minimal_fields(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar']
        })

        self.assertTrue(form.is_valid(), form.errors)

        matchup = form.save()

        self.assertEqual(matchup.title, 'foo vs bar')
        self.assertEqual(matchup.description, '')
        self.assertEqual(matchup.movies, ['foo', 'bar'])
        self.assertEqual(matchup.period, '')

    def test_title_cannot_be_omitted(self):
        form = MatchupForm(self.request, {
            'description': 'The entire foo trilogy',
            'movies': ['foo1', 'foo2', 'foo3']
        })

        self.assertFalse(form.is_valid())
        self.assertIn('title', form.errors)
        self.assertIn('required', *form.errors['title'])

    def test_title_cannot_be_blank(self):
        form = MatchupForm(self.request, {
            'title': '',
            'description': 'The entire foo trilogy',
            'movies': ['foo1', 'foo2', 'foo3']
        })
        self.assertFalse(form.is_valid())
        self.assertIn('title', form.errors)
        self.assertIn('required', *form.errors['title'])

    def test_movies_cannot_be_omitted(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar'
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)
        self.assertIn('required', *form.errors['movies'])

    def test_movies_cannot_be_empty(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': []
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)
        self.assertIn('required', *form.errors['movies'])

    def test_movies_must_be_valid(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs quux',
            'movies': ['foo', 'quux']
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)

    def test_period_must_be_valid_if_provided(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar'],
            'period': 'blah'
        })
        self.assertFalse(form.is_valid())
        self.assertIn('period', form.errors)
        self.assertIn('valid', *form.errors['period'])

    def test_featured_only_allowed_for_featured_contributors(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar'],
            'featured': True
        })
        self.assertFalse(form.is_valid())
        self.assertIn('featured', form.errors)

        self.user.is_staff = True
        self.user.save()

        # Re-initialize form to run validation again with updated data.
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar'],
            'featured': True
        })
        self.assertTrue(form.is_valid())

==> bomojo-0.7.1.tar.gz: bomojo-0.7.1/bomojo/matchups/tests/test_forms.py <==
from django.contrib.auth.models import User
from django.test import RequestFactory, TestCase, override_settings

from bomojo.matchups.forms import MatchupForm
from bomojo.matchups.tests.helpers import create_movie


class MatchupFormTest(TestCase):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        create_movie('Foo')
        create_movie('Foo 2', external_id='foo2')
        create_movie('Foo 3', external_id='foo3')
        create_movie('Bar')

    def setUp(self):
        super().setUp()
        self.user = User.objects.create(username='joe',
                                        email='joe@example.com',
                                        password='top_secret')
        self.request = RequestFactory().post('/matchup')

        # Simulate the user being authenticated.
        self.request.user = self.user

    def test_happy_path(self):
        form = MatchupForm(self.request, {
            'title': 'foo trilogy',
            'description': 'The entire foo trilogy',
            'movies': ['foo', 'bar'],
            'period': '30d'
        })

        self.assertTrue(form.is_valid(), form.errors)

        matchup = form.save()

        self.assertEqual(matchup.title, 'foo trilogy')
        self.assertEqual(matchup.description, 'The entire foo trilogy')
        self.assertEqual(matchup.movies, ['foo.htm', 'bar.htm'])
        self.assertEqual(matchup.period, '30d')

    def test_minimal_fields(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar']
        })

        self.assertTrue(form.is_valid(), form.errors)

        matchup = form.save()

        self.assertEqual(matchup.title, 'foo vs bar')
        self.assertEqual(matchup.description, '')
        self.assertEqual(matchup.movies, ['foo.htm', 'bar.htm'])
        self.assertEqual(matchup.period, '')

    def test_parses_movie_ids(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo.htm', 'bar.htm']
        })

        self.assertTrue(form.is_valid(), form.errors)

        matchup = form.save()

        self.assertEqual(matchup.title, 'foo vs bar')
        self.assertEqual(matchup.description, '')
        self.assertEqual(matchup.movies, ['foo.htm', 'bar.htm'])
        self.assertEqual(matchup.period, '')

    def test_title_cannot_be_omitted(self):
        form = MatchupForm(self.request, {
            'description': 'The entire foo trilogy',
            'movies': ['foo1', 'foo2', 'foo3']
        })

        self.assertFalse(form.is_valid())
        self.assertIn('title', form.errors)
        self.assertIn('required', *form.errors['title'])

    def test_title_cannot_be_blank(self):
        form = MatchupForm(self.request, {
            'title': '',
            'description': 'The entire foo trilogy',
            'movies': ['foo1', 'foo2', 'foo3']
        })
        self.assertFalse(form.is_valid())
        self.assertIn('title', form.errors)
        self.assertIn('required', *form.errors['title'])

    def test_movies_cannot_be_omitted(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar'
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)
        self.assertIn('required', *form.errors['movies'])

    def test_movies_cannot_be_empty(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': []
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)
        self.assertIn('required', *form.errors['movies'])

    def test_movies_must_be_valid(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs quux',
            'movies': ['foo', 'quux']
        })
        self.assertFalse(form.is_valid())
        self.assertIn('movies', form.errors)

    def test_period_must_be_valid_if_provided(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar'],
            'period': 'blah'
        })
        self.assertFalse(form.is_valid())
        self.assertIn('period', form.errors)
        self.assertIn('valid', *form.errors['period'])

    def test_featured_only_allowed_for_featured_contributors(self):
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar'],
            'featured': True
        })
        self.assertFalse(form.is_valid())
        self.assertIn('featured', form.errors)

        self.user.is_staff = True
        self.user.save()

        # Re-initialize form to run validation again with updated data.
        form = MatchupForm(self.request, {
            'title': 'foo vs bar',
            'movies': ['foo', 'bar'],
            'featured': True
        })
        self.assertTrue(form.is_valid())
